Type-state buffer pool.
Structs
- Buffer
- A buffer with type-state tracking ownership.
- Buffer
Pool - Fixed-capacity buffer pool with explicit lifecycle transitions.
- Completed
- Marker type for buffers returned from the backend with data available.
- Owned
- Marker type for buffers owned by user code.
- Pool
- Marker type for buffers part of a special pool.
- Submitted
- Marker type for buffers currently owned by the backend.